@@ -13,10 +13,12 @@
 // limitations under the License.
 
 //! HTTP Protocol Implementation
-//! 
-/// HTTP Transport Implementation
+//!
+
 mod transport;
 
+mod rustls;
+
 use crate::http::transport::TlsTransport;
 use std::result::Result;
 use std::io::{Error, ErrorKind};
